@@ -2,7 +2,7 @@ from sys import exc_info
 import yaml
 import logging
 import logging.config
-from log_config import load_configuration
+from .log_config import load_configuration
 
 log_config = load_configuration()
 
